must

package
v0.0.0-...-00a1424 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 1, 2025 License: MIT Imports: 0 Imported by: 29

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Must

func Must(err error)

Must is a helper that wraps a call to a function returning (error) and panics if the error is non-nil.

func Must2

func Must2[T any](val T, err error) T

Must2 is a helper that wraps a call to a function returning (T, error) and panics if the error is non-nil.

Types

This section is empty.

Jump to